function [GMAlat GMAlon]=GDZ2GMA(Alt,Latd,Lond)

%% By Martin Lisa 2010

%Input variables
% Alt : Input Altitude over ground in Km
% Latd : Input Geodetic latitude [-90,90] 
% Lond : Input Geodetic longitude [-180,180]

% Output variables
% GMAlat : Output Geomagnetic Latitude (-90,90)
% GMAlon : Output Geomagnetic Longitude (-180,180)

A=6378.135;      % semi major axis, world spheroid, WGS 1972
B=6356.750;      % semi minor axis, world spheroid, WGS 1972

% Conversion from geodetic to geocentric coordinates

X=A/sqrt(1+((B/A)^2)*(tand(Latd))^2);
Y=((B/A)^2)*tand(Latd)*X;
XP=X+Alt*cosd(Latd);
YP=Y+Alt*sind(Latd);
R=sqrt((XP^2)+(YP^2));
Lat=90-acosd(YP/R);
Lon=Lond;

% IGRF coordinates for the geomagnetic North pole year 2009
Latmnp=80;
Lonmnp=-72.1;
alpha=90-Latmnp;

% Conversion from geocentric to geomagnetic coordinates
% Aplying the cosine rule to a spherical triangle
a=sind(Lat);
b=cosd(Lat);
c=cosd(alpha);
d=sind(alpha);
e=sind(Lon-Lonmnp);
f=cosd(Lon-Lonmnp);
G=[-180+Lonmnp -90+Lonmnp 90+Lonmnp 180+Lonmnp];
GMAlat=asind(a*c+b*d*f);
% and applying the sine rule
h=cosd(GMAlat);
i=sind(GMAlat);
temp=asind((b*e)/h);

%check for obtuse angles to determine which quadrant
obt=sind(Latmnp)*i;
if (a>=obt) GMAlon=180-temp;
else GMAlon=temp;
end;
if (GMAlon>=180) GMAlon=GMAlon-360;    
end