% Main project file
clear all
close all
global dirnm;
global dirnm_Odin;
global dirnm_Aura;
global dirnm_Odin_ht;
global dirnm_Aura_ht;
global path_data_input_odin;
global path_data_output_odin;
global path_data_input_aura;
global path_data_output_aura;
global path_data_output_odin_aura;
global Sat;
global Sat1;
global Sat2;
global Sat3;
global prod;
global year;
global month;
global startday;
global days;
global dayc;
global Altitude;
global days;
global min_resp;
global Species;
global Quality_thr;
global Converg_thr_O3;
global Converg_thr_OH;
global dayvs;
global dayvc;
global dayvn;
global SpeciesName; 
global valt;
%% Input parameters 

year=2009;
month=07;
startday=17;    % Startday for average
days=5;         % Days to be averaged over from Startday
endday=startday+days-1;
dayvs=[year, month, startday,0,0,0]; % Vector of date. Startday.
dayc=22;          % start day to be compared to average
dayvc=[year, month, dayc,0,0,0]; % Vector of date. Day to be compared.
Altitude=72;    % Altitude of interest
SpeciesName='O3';
Sat1='Odin';    % Available Satellites for data analysis
Sat2='Aura';
Sat3='Odau';
Sat=Sat1;        % Choose either Odin or Aura to be analysed first
odin=strcmp(Sat,Sat1);
aura=strcmp(Sat,Sat2);
vlat=[-85 -80 -75 -70 -65 -60 -55 -50 -45 -40 -35 -30 -25];
valt=[50 55 60 65 70 75 80 85 90];
vdays=[startday:endday];
%valt=[0 500 1000 1500 2000];
%% Choice of ODIN products available
%
% Level 1
%'IM_AC1c': Species are {'H2O_5570','O3_5570','TEMP_5570','PRES_5570'}
%'IM_AC1de': Species are{'H2O-171_5517' 'O3-5517' 'NO_5517' 'H2O-cont_5517' ' TEMP_5517' 'Pres_5517}
%
% Level 2 
%'SM_AC2ab': Species are {'ClO_5018' 'O3-666_5018' 'N2O_5018 '}

lev=cellstr(['IM_AC1c ';'IM_AC1de';'SM_AC2ab']);

prod=char(lev(3,1));     % Choose the level product here by first index

Species=2;      % Choose the species here from the arrays above

% For Aura O3 is only available as level 2 product at 240 GHz

%% Quality settings for Odin and Aura
min_resp=0;   % Minimum measurement response for ODIN
Quality_thr=0.6; % Quality threshold for the Aura-MLS O3 product
Converg_thr_O3=1.18; % Convergence threshold for Aura-MLS O3 product
Converg_thr_OH=1.1; % Convergence threshold for Aura-MLS OH product


%% Paths for input and output files

path_data_input_odin=['/home/gudrun/martilis/Matlab/Master_Project_Satellite_Mapping_O3/Odin_SMR/Data/Odin_Raw/SMRhdf/Qsmr-2-1/',prod];
path_data_output_odin='/home/gudrun/martilis/Matlab/Master_Project_Satellite_Mapping_O3/Odin_SMR/Data/Output_data/';
path_data_input_aura=['/home/gudrun/martilis/Matlab/Master_Project_Satellite_Mapping_O3/Aura_MLS/Data/MLS_Raw/'];
path_data_output_aura='/home/gudrun/martilis/Matlab/Master_Project_Satellite_Mapping_O3/Aura_MLS/Data/Output_data/';
path_data_output_odin_aura='/home/gudrun/martilis/Matlab/Master_Project_Satellite_Mapping_O3/Odin_SMR_and_Aura_MLS/Output_data/';
    


%% Data analysis and plotting
zm_avg=[];
data_n_Aura=[];
data_n_Odin=[];
l2_data_n_both=[];
troll_vmr=[];
troll_temp=[];
% Analyse and plot data from one day at a time in Geo and Mag coordinates
for k=1:days
    dayn=(startday-1)+k;
    dayvn=[year, month, dayn,0,0,0];
    
    disp(['Analysing data above Antarctica from the ',datestr(dayvn)]);
    
    % This function reads the hdf data from the Odin and MLS satellites and
    % converts data from the day of interest (dayn) to structures for 
    % one altitude and all altitudes. 
    
   [data_Odin data_Aura l2_data_Odin l2_data_Aura]=Satellite_info(dayn);
    
    % Create an output text file from the one height structure and return a
    % directory name for output
    
    nd=1;   % Text file for one day and one altitude
    
   %Create_text_file(nd,data_Odin,data_Aura);
   
   % Create output folders for both satellites
   
   if (nd==0 || nd==1) nm=num2str(strrep(datestr(dayvn,24),'/','_'));
   else nm=['Data_of_' num2str(nd) '_days'];end
   dirnm_Odin_Aura=[path_data_output_odin_aura nm];
   if ~exist(dirnm_Odin_Aura) mkdir(dirnm_Odin_Aura);end;
   dir_eps=[dirnm_Odin_Aura '/eps'];
   dir_png=[dirnm_Odin_Aura '/png'];
   if ~exist(dir_eps) mkdir(dir_eps);end;
   if ~exist(dir_png) mkdir(dir_png);end;
   
   % Calculate zonal mean and plot zonal mean for one day Odin
   
   %zm_o=calculate_zonalmean(l2_data_Odin,SpeciesName,'altitude',[50 90],'lat',vlat,valt);
   %plot_zonalmean(zm_o,SpeciesName,'altitude',[0 3.5*10^-6],[50 90],[-90 -25],'X',[dirnm_Odin '/']);
   
   
   % Calculate zonal mean and plot zonal mean for one day Aura
   %zm_a=calculate_zonalmean(l2_data_Aura,SpeciesName,'altitude',[50 90],'lat',vlat,valt);
   %plot_zonalmean(zm_a,SpeciesName,'altitude',[0 3.5*10^-6],[50 90],[-90 -25],'X',[dirnm_Aura '/'],[datestr(dayvs,24)]);
   
   % Make plots of the data 
  l2_data_both=[l2_data_Odin l2_data_Aura]; % All altitudes
  data_both=[data_Odin data_Aura];          % One altitude
 
  % Calculate zonal mean for one day for both satellites 
  
   zm_b=calculate_zonalmean(l2_data_both,SpeciesName,'altitude',[50 90],'lat',vlat,valt);
  
   % Calculate zonal mean only at Troll magnetic latitude -62
  
   zm_t=calculate_zonalmean(l2_data_both,SpeciesName,'altitude',[50 90],'lat',-62,valt);
  
   % Plot zonal mean for one day
   
   %plot_zonalmean(zm_b,SpeciesName,'altitude',[0 10*10^-9],[50 90],[-90 -25],'png',[dir_png '/']);
   
   % Plot southern hemisphere map for one day
   
   %Plot_Antarctic_Map(nd,3.5,0,data_both);
    
   % Calculate sum of zonal mean for several days
    meanvmr_new=zm_b.meanvmr;
    meanlat_new=zm_b.meanlat;
    troll_new=zm_t.meanvmr;
    if k~=1
    meanvmr_sum=meanvmr_old+meanvmr_new;
    meanlat_sum=meanlat_old+meanlat_new;
    meanvmr_old=meanvmr_sum;
    meanlat_old=meanlat_sum;
    else meanvmr_old=meanvmr_new;
        meanlat_old=meanlat_new;
    end;
    troll_vmr=[troll_vmr; troll_new];cd
    data_n_Odin=[data_n_Odin data_Odin];
    data_n_Aura=[data_n_Aura data_Aura];
    l2_data_n_both=[l2_data_n_both l2_data_both];
    zm_t=[];
    troll_new=[];
    data_Odin=[];
    data_Aura=[];
    l2_data_Odin=[];
    l2_data_Aura=[];
    l2_data_both=[];
 
    

end;

% Plot time series of zonal mean at Troll latitude

zm_troll=zm_b;
zm_troll.meanvmr=troll_vmr;
zm_troll.lat_type='time';
zm_troll.meanlat=vdays;
zm_troll.name=[SpeciesName '_Troll_time_' num2str(days) '_days'];
dirnm_Odin_Aura_time=[path_data_output_odin_aura 'Time_series'];
if ~exist(dirnm_Odin_Aura_time) mkdir(dirnm_Odin_Aura_time);end;

%plot_zonalmean(zm_troll,SpeciesName,'altitude',[0 3.5*10^-6],[50 90],[startday endday],'png',[dirnm_Odin_Aura_time '/'],[SpeciesName ' - Mean. 62 S']);

troll_avg=mean(troll_vmr(1:5,:));
for g=1:length(troll_vmr(:,1));
%troll_pct(g,:)=((troll_vmr(g,:)-troll_avg)./troll_avg)*100;
troll_pct(g,:)=(troll_vmr(g,:)-troll_avg);

end;
zm_troll.meanvmr=troll_pct;
zm_troll.name=[SpeciesName '_Troll_time_' num2str(days) '_days_perc'];
%plot_zonalmean(zm_troll,SpeciesName,'altitude',[-1*10^-6 10^-6],[50 90],[startday endday],'png',[dirnm_Odin_Aura_time '/'],[SpeciesName ' - Change from pre-storm avg. 62 S']);

%zm_dt=calculate_zonalmean(l2_data_both,SpeciesName,'altitude',[50 90],'lat',-62,valt);
% troll_new=zm_dt.meanvmr;
% troll_pct=((troll_new-troll_avg)./troll_avg)*100;
% zm_troll.meanvmr=troll_pct;
% zm_troll.name=['O3_Troll_time_' num2str(days) '_days'];
 

%if length(zm_troll.meanvmr)<1;a=1;end
%% Average of zonal mean for days before the storm

meanvmr_avg=meanvmr_sum./k;
meanlat_avg=meanlat_sum./k;
zm_b.meanvmr=meanvmr_avg;
zm_b.meanlat=meanlat_avg;
zm_b.name=[SpeciesName,'_zmean_Mag_average'];
dirnm_Odin_Aura_avg=[path_data_output_odin_aura 'Average'];
if ~exist(dirnm_Odin_Aura_avg) mkdir(dirnm_Odin_Aura_avg);end;
plot_zonalmean(zm_b,SpeciesName,'altitude',[0 3.5*10^-6],[50 90],[-90 -25],'png',[dirnm_Odin_Aura_avg '/'],[SpeciesName ' - Zonal Mean - Average 5 days pre-storm']);

%% Create text file and make geomagnetic map with datapoints of several days 
% Separate maps for Odin and Aura satellites

%Create_text_file(days,data_n_Odin,data_n_Aura);


%Plot_Antarctic_Map(days,3.5,0,data_n_Odin,data_n_Aura);

% Same map for Odin and Aura satellites
 
data_total=[data_n_Odin data_n_Aura];

avg_int=Plot_Antarctic_Map(days,3.5,0,data_total);

% Create text file and make map with datapoints of the day to be compared 
% Same map for Odin and Aura satellites

 
for w=1:7
zm_dc=[];
meanvmr_new=[];
meanlat_new=[];
meanvmr_pct=[]; 
dayn=(dayc-1)+w;
dayvn=[year, month, dayn,0,0,0];
%dayvc=[year, month, dayc+(w-1),0,0,0];
%day_run=dayc+(w-1);

[data_dc_Odin data_dc_Aura l2_data_dc_Odin l2_data_dc_Aura]=Satellite_info(dayn);

% GeoMag Map
    
data_dc=[data_dc_Odin data_dc_Aura];

%Create_text_file(0,data_dc_Odin,data_dc_Aura);
dc_int=Plot_Antarctic_Map(0,3.5,0,data_dc);

% Zonal mean
 l2_data_dc_both=[l2_data_dc_Odin l2_data_dc_Aura];
 zm_dc=calculate_zonalmean(l2_data_dc_both,SpeciesName,'altitude',[50 90],'lat',vlat,valt);
 
 
 meanvmr_new=zm_dc.meanvmr;
 meanlat_new=zm_dc.meanlat;
 meanvmr_pct=((meanvmr_new-meanvmr_avg)./meanvmr_avg)*100;
 %meanvmr_pct=((meanvmr_new-meanvmr_avg));
 
 meanlat=meanlat_new;
 zm_dc.meanvmr=meanvmr_pct;
 zm_dc.meanlat=meanlat;
 
 zm_dc.name=[zm_dc(1).name '_chg_avg'];
 
% Plot percentage change og species OH
% plot_zonalmean(zm_dc,SpeciesName,'altitude',[-1*10^-9 1*10^-9],[50 90],[-90 -25],'png',[dirnm_Odin_Aura_avg '/'],[SpeciesName ' - ' zm_dc.startdate ' change from pre-storm avg']);

%plot_zonalmean(zm_dc,SpeciesName,'altitude',[-50 50],[50 90],[-90 -25],'png',[dirnm_Odin_Aura_avg '/'],[SpeciesName ' - ' zm_dc.startdate ' change from pre-storm avg']);
    
% Make plots of the data and return interpolated data
n=size(avg_int,1);
m=size(avg_int,2);  

 
    for i=1:n
        for j=1:m
            if (dc_int(i,j)==NaN | avg_int(i,j)==NaN) Chg(i,j)=NaN;
            else
                Chg(i,j)=((dc_int(i,j)-avg_int(i,j))./avg_int(i,j))*100;
                
            end;
        end;
    end;
Sat=Sat3;  
Plot_averaged_data(Chg,days,[-100,100],'Pct',datestr(dayvn,24))
end;    
    




