function Z2=Plot_Antarctic_Map(nd,ul,mk,data_Odin,data_Aura)
global min_resp;
global Altitude;
global dirnm;
global dirnm_Odin;
global dirnm_Aura;
global dirnm_Odin_ht;
global dirnm_Aura_ht;
global Sat;
global Sat1;
global Sat2;
global Sat3;
global path_data_output_odin_aura;
global dayvn;

%% Input fields

% nd: Number of days to be plotted
% ul: Upper limit for species in colorbar (the red value) in ppmv
% mk: Flag for showing plot markers
% data_Odin: structure for Odin satellite
% data_Aura: structure for Aura satellite


load coasts.mat
colon=coasts(:,1)./100-180;
colat=coasts(:,2)./100-90;
L=length(colon);

f=isnan(colat);
g=isnan(colon);
for v=1:L;
    if (f(v)~=1 || g(v)~=1);
        [mcolat(v) mcolon(v)]=GDZ2GMA(60,colat(v),colon(v));
    else
        mcolat(v)=NaN;
        mcolon(v)=NaN;
    end;
end;
mcolon=mcolon';
mcolat=mcolat';
mrad=ones(length(mcolon),1);

if nargin<5 
    r=2;
Sat=Sat3;
data=data_Odin;
else Sat=Sat1;r=1;
end;

while r<=2
    
    if Sat==Sat1 data=data_Odin;end;
    if Sat==Sat2 data=data_Aura;end;
    
    % fill 180deg longitude gap ...
    %
    I=find ([data.GeodeticLon] < -140);
    datares1=data(I);
    for i=1:length(datares1)
        datares1(i).GeodeticLon = datares1(i).GeodeticLon+360;
    end
    data=[data datares1];
    I=find ([data.GeodeticLon] > 140);
    datares1=data(I);
    for i=1:length(datares1)
        datares1(i).GeodeticLon = datares1(i).GeodeticLon-360;
    end
    data=[data datares1];
    
    K=find ([data.GeoMagLon] < -140);
    datares2=data(K);
    for i=1:length(datares2)
        datares2(i).GeoMagLon = datares2(i).GeoMagLon+360;
    end
    data=[data datares2];
    K=find ([data.GeoMagLon] > 140);
    datares2=data(K);
    for i=1:length(datares2)
        datares2(i).GeoMagLon = datares2(i).GeoMagLon-360;
    end
    data=[data datares2];
    
    for p=1:length(data);
        [prof(p)]=data(p).Profile;
        if (data(p).SunZD>=105); % && data(p).SunZD<=140);
            profn(p)=data(p).Profile;
        else profn(p)=NaN;end; % Profile for nighttime
        %[MResp(p)]=data(p).MeasResp;
        [gdzlat(p)] =data(p).GeodeticLat;
        [gdzlon(p)] =data(p).GeodeticLon;
        [gmalat(p)] =data(p).GeoMagLat;
        [gmalon(p)] =data(p).GeoMagLon;
        [time(p)]=datenum(data(p).Time);
        if (prof(p)<=0) prof(p)=NaN;end;
    end
    
    
    % Erase data points where profile values are NaNs
    
    gmalon=real(gmalon);
    nindex=isnan(profn);
    profn(nindex)=[];
    gdzlat(nindex)=[];
    gdzlon(nindex)=[];
    gmalat(nindex)=[];
    gmalon(nindex)=[];
    time(nindex)=[];
    %index= MResp<min_resp;
    %prof(index)=NaN;
    %index=find(MResp>=min_resp);
    %disp(['# profiles: ',num2str(length(index))]);
    %if length(index) < 10
    %    disp(['Error (Plot_Antarctic_Map): not enough data ... Plotting aborted.']);
    %    return
    %end
    
    lat=-90:1:90;
    lon=-180:1:180;
    [XG ,YG]=meshgrid(lon,lat);
   
    [x y z]=sphere(2*24);
    F=TriScatteredInterp(gdzlon',gdzlat',profn','natural');
    G=TriScatteredInterp(gmalon',gmalat',profn','natural');
    Z1=F(XG,YG);
    Z2=G(XG,YG);
   
    
  
    %% Plot mapping the species of interest in geodetic coordinates
    
    close all;
    
    figure(1);
    cla;clf;
    set(gcf,'Visible','on');
    set(gcf,'InvertHardcopy','off');
    set(gcf,'Color',[1 1 1]);
    axes('position', [0.05,0.05,0.9,0.9]);
    axis off;axis square;
    caxis ([0 ul]);
    
    hearth=surface(x,y,z,'cdata',Z1*(10^6),'facecolor','texture','edgecolor','none');
    [cx,cy,cz]=sph2cart(colon/180*pi,colat/180*pi,ones(length(colon),1));
    shcoasts = line(cx,cy,cz,'color',[0 0 0],'linewi',1.1);
    view(-90,-90);
    rotate([hearth,shcoasts],[0 0 1],180);
    
    % Plot markers for scans of the orbit
    
    if mk
        [mx,my,mz]=sph2cart([gdzlon]/180*pi,[gdzlat]/180*pi,ones(length([gdzlon]),1)'); 
    shorbit=line(mx,my,mz,'color',[0.5 0.5 0.5],'linesty','none','LineWidth',0.7,'marker','o','MarkerSize',4,'EraseMode','none');
    rotate(shorbit,[0 0 1],180);
    
    else shorbit=zeros(gdzlon);
    end;
    
    % Plot Troll
    [tx ty tz]=sph2cart([2.5]/180*pi,[-72]/180*pi,1);
    plot_troll=line(tx,ty,tz,'color',[1 0 0],'linesty','none','LineWidth',0.7,'marker','o','MarkerFaceColor',[1 0 0],'MarkerSize',8,'EraseMode','none');
    rotate(plot_troll,[0 0 1],180);
    
    % Show grid
    
    plotgrid(-90:10:90,-180:30:180,'sphere');
    if Sat==Sat3;
        Satnm='Odin and Aura';
    else Satnm=Sat;end;
    bar_title1=[Satnm,' satellites. ',data(1).SpeciesName,' map at ',num2str(Altitude),' Km of altitude.'];
    
    text(-1.05,0,bar_title1,'fontsize' ,13,'Fontweight','demi','interpreter','none','horiz','center');
    if nd==1 bar_title2=['Geographic coordinates. Date: ' data(1).Date];
    elseif nd==0 bar_title2=['Geographic coordinates. Date: ' datestr(dayvn,24)];
    else bar_title2=['Geographic coordinates. ', num2str(nd),' days of data from the ',data(1).Date];end;
    
    text(1.05,0,bar_title2,'fontsize' ,13,'Fontweight','demi','interpreter','none','horiz','center');
    if Sat~=Sat3 text(0,-1.55,[data(1).SpeciesName ' [ppmv]'],'fontsize' ,13,'Fontweight','demi','interpreter','none','horiz','center','Rotation',90)
    else text(0,-1.55,['O3 [ppmv]'],'fontsize' ,13,'Fontweight','demi','interpreter','none','horiz','center','Rotation',90);
    end;  
    cmap=colormap(jet(16));
    %cmap=colormap;
    cmap(1,:)=1.;
    colormap(cmap);
    hcolorbar=colorbar;
    set(hcolorbar,'fontsize' ,10,'Fontweight','demi');
        
    % Save plot
    dt=data(1).Date;
    sn=data(1).SpeciesName;
    set(gcf,'InvertHardcopy','off');
    set(gcf,'PaperType','A4');
    set(gcf,'PaperOrientation','landscape');
    set(gcf,'PaperPositionMode','auto');
    datep=strrep(dt,'/','_');
    specp=strrep(sn,' ',[]);
    datec=strrep(datestr(dayvn,24),'/','_');
    if nd~=1 && nd~=0 nm=[num2str(nd) '_days_'];
    else nm=[];end;
    
    if Sat==Sat1
        dir_eps=[dirnm_Odin_ht '/eps'];
        dir_png=[dirnm_Odin_ht '/png'];
        if ~exist(dir_eps) mkdir(dir_eps);end;
        if ~exist(dir_png) mkdir(dir_png);end;
        png_name=fullfile(dir_png,['Odin_',specp,'_',num2str(Altitude),'_Km_GeoMap_',nm,datep,'.png']);
        eps_name=fullfile(dir_eps,['Odin_',specp,'_',num2str(Altitude),'Km_GeoMap_',nm,datep,'.eps']);
    elseif Sat==Sat3
        if nd~=0 datem=datep; else datem=datec;end;
        dir_1=[path_data_output_odin_aura datem '/' num2str(Altitude) '_Km'];
        dir_eps=[dir_1 '/eps'];
        dir_png=[dir_1 '/png'];
        if ~exist(dir_1) mkdir(dir_1);end;
        if ~exist(dir_eps) mkdir(dir_eps);end;
        if ~exist(dir_png) mkdir(dir_png);end;
        png_name=fullfile(dir_png,['Odin_Aura_O3_',num2str(Altitude),'_Km_GeoMap_',nm,datem,'.png']);
        eps_name=fullfile(dir_eps,['Odin_Aura_O3_',num2str(Altitude),'Km_GeoMap_',nm,datem,'.eps']);
        
    else
        dir_eps=[dirnm_Aura_ht '/eps'];
        dir_png=[dirnm_Aura_ht '/png'];
        if ~exist(dir_eps) mkdir(dir_eps);end;
        if ~exist(dir_png) mkdir(dir_png);end;
        png_name=fullfile(dir_png,['Aura_',specp,'_',num2str(Altitude),'_Km_GeoMap_',nm,datep,'.png']);
        eps_name=fullfile(dir_eps,['Aura_',specp,'_',num2str(Altitude),'Km_GeoMap_',nm,datep,'.eps']);
    end;
    disp(['Printing to file ',png_name,' ... ']);
    print('-dpng',['-f1'],png_name);
    
    disp(['Printing to file ',eps_name,' ... ']);
    print('-depsc',['-f1'],eps_name);
    
    %
    
    
    
    %% Plot mapping the species of interest in geomagnetic coordinates
    figure(2);
    cla;clf;
    set(gcf,'Visible','on');
    set(gcf,'InvertHardcopy','off');
    set(gcf,'Color',[1 1 1]);
    axes('position', [0.05,0.05,0.9,0.9]);
    axis off;axis square;
    caxis ([0 ul]);
    hearth=surface(x,y,z,'cdata',Z2*(10^6),'facecolor','texture','edgecolor','none');
    [cx,cy,cz]=sph2cart((mcolon)/180*pi,(mcolat)/180*pi,mrad);
    shcoasts = line(cx,cy,cz,'color',[0 0 0],'linewi',1.1);
    
    
    % Plot markers for scans of the orbit
    if mk
    [mx,my,mz]=sph2cart([gmalon]/180*pi,[gmalat]/180*pi,ones(length([gmalon]),1)'); %'
    shorbitm=line(mx,my,mz,'color',[0.5 0.5 0.5],'linesty','none','LineWidth',0.7,'marker','o','MarkerSize',4,'EraseMode','none');
    rotate(shorbitm,[0 0 1],180);
    end;
    
    % Plot Troll
    [mlatt mlont]=GDZ2GMA(60,-72,2.5);
    [tx ty tz]=sph2cart([mlont]/180*pi,[mlatt]/180*pi,1);
    plot_troll=line(tx,ty,tz,'color',[1 0 0],'linesty','none','LineWidth',0.7,'marker','o','MarkerFaceColor',[1 0 0],'MarkerSize',8,'EraseMode','none');
    
    view(-90,-90)
    rotate([hearth,shcoasts,plot_troll],[0 0 1],180);
    
    % Zoom and show grid
    %zoom(1.5)
    plotgrid(-90:10:90,-180:30:180,'sphere');
    
    %
    % make sure that NaNs are white ...
    %
    %cmap=colormap;
    %cmap(1,:)=1.;
    %colormap(cmap);
    
    cmap=colormap(jet(16));
    cmap=colormap;
    cmap(1,:)=1.;
    colormap(cmap);
    
    tmp_cdata=get(hearth,'cdata');
    cl=get(gca,'clim');
    tmp_cdata(isnan(tmp_cdata))=cl(1);
    set(hearth,'cdata',tmp_cdata);
    
    % colorbar
    hcolorbar=colorbar;
    set(hcolorbar,'fontsize' ,10,'Fontweight','demi');
    bar_title1=[Satnm,' satellites. ',data(1).SpeciesName,' map at ',num2str(Altitude),' Km of altitude.'];
    text(-1.05,0,bar_title1,'fontsize' ,13,'Fontweight','demi','interpreter','none','horiz','center');
    
    if nd==1 bar_title2=['Geomagnetic coordinates. Date: ' data(1).Date];
    elseif nd==0 bar_title2=['Geomagnetic coordinates. Date: ' datestr(dayvn,24)];
    else
        bar_title2=['Geomagnetic coordinates. ',num2str(nd),' days of data from the ',data(1).Date];end;
    
    text(1.05,0,bar_title2,'fontsize' ,13,'Fontweight','demi','interpreter','none','horiz','center');
    if Sat~=Sat3 text(0,-1.55,[data(1).SpeciesName ' [ppmv]'],'fontsize' ,13,'Fontweight','demi','interpreter','none','horiz','center','Rotation',90)
    else text(0,-1.55,['O3 [ppmv]'],'fontsize' ,13,'Fontweight','demi','interpreter','none','horiz','center','Rotation',90);
    end    
    % Save plot
    
    set(gcf,'InvertHardcopy','off');
    set(gcf,'PaperType','A4');
    set(gcf,'PaperOrientation','landscape');
    set(gcf,'PaperPositionMode','auto');
    datep=strrep(dt,'/',[]);
    specp=strrep(sn,' ',[]);
    if nd~=1 && nd~=0 nm=[num2str(nd) '_days_'];
    else nm=[];end;
      
    if Sat==Sat1
        dir_eps=[dirnm_Odin_ht '/eps'];
        dir_png=[dirnm_Odin_ht '/png'];
        if ~exist(dir_eps) mkdir(dir_eps);end;
        if ~exist(dir_png) mkdir(dir_png);end;
        png_name=fullfile(dir_png,['Odin_',specp,'_',num2str(Altitude),'_Km_MagMap_',nm,datep,'.png']);
        eps_name=fullfile(dir_eps,['Odin_',specp,'_',num2str(Altitude),'Km_MagMap_',nm,datep,'.eps']);
    elseif Sat==Sat3
        dir_1=[path_data_output_odin_aura datem '/' num2str(Altitude) '_Km'];
        dir_eps=[dir_1 '/eps'];
        dir_png=[dir_1 '/png'];
        if ~exist(dir_1) mkdir(dir_1);end;
        if ~exist(dir_eps) mkdir(dir_eps);end;
        if ~exist(dir_png) mkdir(dir_png);end;
        png_name=fullfile(dir_png,['Odin_Aura_O3_',num2str(Altitude),'_Km_MagMap_',nm,datem,'.png']);
        eps_name=fullfile(dir_eps,['Odin_Aura_O3_',num2str(Altitude),'Km_MagMap_',nm,datem,'.eps']);
        
    else
        dir_eps=[dirnm_Aura_ht '/eps'];
        dir_png=[dirnm_Aura_ht '/png'];
        if ~exist(dir_eps) mkdir(dir_eps);end;
        if ~exist(dir_png) mkdir(dir_png);end;
        png_name=fullfile(dir_png,['Aura_',specp,'_',num2str(Altitude),'_Km_MagMap_',nm,datep,'.png']);
        eps_name=fullfile(dir_eps,['Aura_',specp,'_',num2str(Altitude),'Km_MagMap_',nm,datep,'.eps']);
    end;
     
    disp(['Printing to file ',png_name,' ... ']);
    print('-dpng',['-f2'],png_name);
    
    disp(['Printing to file ',eps_name,' ... ']);
    print('-depsc',['-f2'],eps_name);
    data=[];
  
  
     
    figure(3);
     cla;clf;
    set(gcf,'Visible','on');
    set(gcf,'InvertHardcopy','off');
    set(gcf,'Color',[1 1 1]);
    %axes('position', [0.05,0.05,0.9,0.9]);
    %axis off;axis square;
    axes1=axes('Parent',gcf,'YMinorTick','on',...
    'XTick',[-180 -120 -60 0 60 120 180],...
    'XMinorTick','on',...
    'CLim',[0 ul]);
    xlim(axes1,[-180 180]);
    ylim(axes1,[-80 0]);
    caxis ([0 ul]);
    flat=surface(XG,YG,Z1*(10^6),'LineStyle','none',...
    'FaceColor','interp');
    cmap=colormap(jet(16));
    %cmap=colormap;
    cmap(1,:)=1.;
    colormap(cmap);
    tmp_cdata=get(flat,'cdata');
    cl=get(gca,'clim');
    tmp_cdata(isnan(tmp_cdata))=cl(1);
    set(flat,'cdata',tmp_cdata);
    xlabel('Longitude');

    % Create ylabel
    ylabel('Latitude');
    bar_tit=[sn,' map at ',num2str(Altitude),' Km of altitude. Date:' bar_title2];
    text(-1.05,2,bar_tit,'fontsize' ,13,'Fontweight','demi','interpreter','none','horiz','center');
    
    set(gcf,'InvertHardcopy','off');
    set(gcf,'PaperType','A4');
    set(gcf,'PaperOrientation','landscape');
    set(gcf,'PaperPositionMode','auto');
    datep=strrep(dt,'/','_');
    specp=strrep(sn,' ',[]);
    datec=strrep(datestr(dayvn,24),'/','_');
    if nd~=1 && nd~=0 nm=[num2str(nd) '_days_'];
    else nm=[];end;
    
    if Sat==Sat1
        dir_eps=[dirnm_Odin_ht '/eps'];
        dir_png=[dirnm_Odin_ht '/png'];
        if ~exist(dir_eps) mkdir(dir_eps);end;
        if ~exist(dir_png) mkdir(dir_png);end;
        png_name=fullfile(dir_png,['Odin_',specp,'_',num2str(Altitude),'_Km_Flat_GeoMap_',nm,datep,'.png']);
        eps_name=fullfile(dir_eps,['Odin_',specp,'_',num2str(Altitude),'Km_Flat_GeoMap_',nm,datep,'.eps']);
    elseif Sat==Sat3
        if nd~=0 datem=datep; else datem=datec;end;
        dir_1=[path_data_output_odin_aura datem '/' num2str(Altitude) '_Km'];
        dir_eps=[dir_1 '/eps'];
        dir_png=[dir_1 '/png'];
        if ~exist(dir_1) mkdir(dir_1);end;
        if ~exist(dir_eps) mkdir(dir_eps);end;
        if ~exist(dir_png) mkdir(dir_png);end;
        png_name=fullfile(dir_png,['Odin_Aura_O3_',num2str(Altitude),'_Km_Flat_GeoMap_',nm,datem,'.png']);
        eps_name=fullfile(dir_eps,['Odin_Aura_O3_',num2str(Altitude),'Km_Flat_GeoMap_',nm,datem,'.eps']);
        
    else
        dir_eps=[dirnm_Aura_ht '/eps'];
        dir_png=[dirnm_Aura_ht '/png'];
        if ~exist(dir_eps) mkdir(dir_eps);end;
        if ~exist(dir_png) mkdir(dir_png);end;
        png_name=fullfile(dir_png,['Aura_',specp,'_',num2str(Altitude),'_Km_Flat_GeoMap_',nm,datep,'.png']);
        eps_name=fullfile(dir_eps,['Aura_',specp,'_',num2str(Altitude),'Km_Flat_GeoMap_',nm,datep,'.eps']);
    end;
    disp(['Printing to file ',png_name,' ... ']);
    print('-dpng',['-f3'],png_name);
    
    disp(['Printing to file ',eps_name,' ... ']);
    print('-depsc',['-f3'],eps_name);
    
    figure(4);
     cla;clf;
    set(gcf,'Visible','on');
    set(gcf,'InvertHardcopy','off');
    set(gcf,'Color',[1 1 1]);
    %axes('position', [0.05,0.05,0.9,0.9]);
    %axis off;axis square;
    axes1=axes('Parent',gcf,'YMinorTick','on',...
    'XTick',[-180 -120 -60 0 60 120 180],...
    'XMinorTick','on',...
    'CLim',[0 ul]);
    xlim(axes1,[-180 180]);
    ylim(axes1,[-90 0]);
    caxis ([0 ul]);
    flat=surface(XG,YG,Z2*(10^6),'LineStyle','none',...
    'FaceColor','interp');
    cmap=colormap(jet(16));
    %cmap=colormap;
    cmap(1,:)=1.;
    colormap(cmap);
    tmp_cdata=get(flat,'cdata');
    cl=get(gca,'clim');
    tmp_cdata(isnan(tmp_cdata))=cl(1);
    set(flat,'cdata',tmp_cdata);
    xlabel('Geomagnetic Longitude');

    % Create ylabel
    ylabel('Geomagnetic Latitude');
    bar_tit=[sn,' map at ',num2str(Altitude),' Km of altitude. Date:' bar_title2];
    text(-1.05,2,bar_tit,'fontsize' ,13,'Fontweight','demi','interpreter','none','horiz','center');
    
    set(gcf,'InvertHardcopy','off');
    set(gcf,'PaperType','A4');
    set(gcf,'PaperOrientation','landscape');
    set(gcf,'PaperPositionMode','auto');
    datep=strrep(dt,'/','_');
    specp=strrep(sn,' ',[]);
    datec=strrep(datestr(dayvn,24),'/','_');
    if nd~=1 && nd~=0 nm=[num2str(nd) '_days_'];
    else nm=[];end;
    
    if Sat==Sat1
        dir_eps=[dirnm_Odin_ht '/eps'];
        dir_png=[dirnm_Odin_ht '/png'];
        if ~exist(dir_eps) mkdir(dir_eps);end;
        if ~exist(dir_png) mkdir(dir_png);end;
        png_name=fullfile(dir_png,['Odin_',specp,'_',num2str(Altitude),'_Km_Flat_MagMap_',nm,datep,'.png']);
        eps_name=fullfile(dir_eps,['Odin_',specp,'_',num2str(Altitude),'Km_Flat_MagMap_',nm,datep,'.eps']);
    elseif Sat==Sat3
        if nd~=0 datem=datep; else datem=datec;end;
        dir_1=[path_data_output_odin_aura datem '/' num2str(Altitude) '_Km'];
        dir_eps=[dir_1 '/eps'];
        dir_png=[dir_1 '/png'];
        if ~exist(dir_1) mkdir(dir_1);end;
        if ~exist(dir_eps) mkdir(dir_eps);end;
        if ~exist(dir_png) mkdir(dir_png);end;
        png_name=fullfile(dir_png,['Odin_Aura_O3_',num2str(Altitude),'_Km_Flat_MagMap_',nm,datem,'.png']);
        eps_name=fullfile(dir_eps,['Odin_Aura_O3_',num2str(Altitude),'Km_Flat_MagMap_',nm,datem,'.eps']);
        
    else
        dir_eps=[dirnm_Aura_ht '/eps'];
        dir_png=[dirnm_Aura_ht '/png'];
        if ~exist(dir_eps) mkdir(dir_eps);end;
        if ~exist(dir_png) mkdir(dir_png);end;
        png_name=fullfile(dir_png,['Aura_',specp,'_',num2str(Altitude),'_Km_Flat_MagMap_',nm,datep,'.png']);
        eps_name=fullfile(dir_eps,['Aura_',specp,'_',num2str(Altitude),'Km_Flat_MagMap_',nm,datep,'.eps']);
    end;
    disp(['Printing to file ',png_name,' ... ']);
    print('-dpng',['-f4'],png_name);
    
    disp(['Printing to file ',eps_name,' ... ']);
    print('-depsc',['-f4'],eps_name);
    
    %
    
      % Plotting time series
    %x=time;
    %y=profn;
   
    %figure(5);
    % cla;clf;
    %set(gcf,'Visible','on');
    %set(gcf,'InvertHardcopy','off');
    %set(gcf,'Color',[1 1 1]);
    %axes1 = axes('Parent',gcf,'YMinorTick','on',...
    %'XTick',[-180 -120 -60 0 60 120 180],...
    %'XMinorTick','on',...
    %'CLim',[0 ul]);
    %xlim(axes1,[-180 180]);
    %ylim(axes1,[-90 0]);
    %hold(axes1,'all');
    %flat=surface('Parent',axes1,'YData',YG,'XData',XG,...
    %'LineStyle','none',...
    %'FaceColor','interp','CData',Z2*(10^6));
   
    %tmp_cdata=get(flat,'cdata');
    %cl=get(gca,'clim');
    %tmp_cdata(isnan(tmp_cdata))=cl(1);
    %set(flat,'cdata',tmp_cdata);
    % Create xlabel
    %xlabel('Geomagnetic Longitude');

    % Create ylabel
    %ylabel('Geomagnetic Latitude');

    
    %axes('position', [0.05,0.05,0.9,0.9]);
    %axis off;axis square;
    %caxis ([0 ul]);
    %flat=surface(XG,YG,Z2*(10^6));
    %cmap=colormap(jet(10));
    %cmap=colormap;
    %cmap(1,:)=1.;
    %colormap(cmap);
    %tmp_cdata=get(flat,'cdata');
    %cl=get(gca,'clim');
    %tmp_cdata(isnan(tmp_cdata))=cl(1);
    %set(flat,'cdata',tmp_cdata);
    Sat=Sat2;
    r=r+1;
  %if x(1)~=x(2) figure(5);
  %stem(x,y);end
end;
end

