function [S_Alt_Odin S_Alt_Aura l2_data_odin l2_data_aura] = Satellite_info(dayn)

global path_data_input_odin;
global path_data_input_aura;
global Altitude;
global Species;
global Quality_thr;
global Converg_thr_O3;
global Converg_thr_OH;
global SpeciesName;
global dayvn;
global valt;

% Created: Martin Lisa, 2010.
% This function will load one day worth of data from the two satellites.
% It will then create several structure files for selected parameters.

%% Data analysis for Odin
% For the satellite ODIN it reads the data with the function
% read_l2_smr.m
% Only scans of quality 0 (good) are used in the new structures S and l2_data_odin
if ~isempty(strfind(SpeciesName,'O3'));
    files=dir(fullfile(path_data_input_odin, '*.L2P'));
    n_orbits=size(files,1);
    l2_data=[];
    n_orb=[];
    for i=1:n_orbits
        filename=fullfile(path_data_input_odin,files(i).name);
        l2temp = read_l2_smr(filename);
        scans=size(l2temp,2);
        for n=1:scans
            if (l2temp(n).Day==dayn & l2temp(n).Quality==0)
                l2_data=[l2_data l2temp(n)];
            end;
        end;
        if ~isempty(l2temp) l2temp=[];
            n_orb=n_orb+1;
        end;
        
    end
    
    % check for data ...
    if isempty(l2_data)
        error('ERROR: no data for specified days - data structure empty ...');
        
    end;
    
    %% A new structure file S is created containing selected parameters.
    
    % It only includes scans taken for geodetic latitudes <0 degrees.
    %AvAlt=60; % Average Altitude for scans [10,110] Km over sea level
    Nsc = size (l2_data,2); %Number of scans for the l2_data structure
    
    
    N=1; % Index for the structure l2_data
    n=1; % Index for the structure S
    while N<=Nsc
        Lat(N)=l2_data(N).Latitude;
        if Lat(N)<=0
            
           o=zeros(length(l2_data(N).ZPT),1); 
            [GMLat GMLon]=GDZ2GMA(60,l2_data(N).Latitude,l2_data(N).Longitude);
            GMLat_Odin(N,1)=GMLat;
            GMLon_Odin(N,1)=GMLon;
            S(n) = struct('OrbitName',char(l2_data(N).OrbitFilename),...
                'ScanNo', double(l2_data(N).ScanNo),...
                'Date', datestr(dayvn,'dd/mm/yyyy'),...
                'Time', datestr(dayvn,'HH:MM:SS'),...
                'SunZD', double(l2_data(N).SunZD),...
                'GeodeticLat',double(l2_data(N).Latitude),...
                'GeodeticLon',double(l2_data(N).Longitude),...
                'GeoMagLat',double(GMLat),...
                'GeoMagLon', double(GMLon),...
                'SpeciesName',char(l2_data(N).SpeciesNames{Species}),...
                'Altitudes',double(l2_data(N).Altitudes{Species}),...
                'Profile',double(l2_data(N).Profiles{Species}),...
                'MeasError',double(l2_data(N).MeasError{Species}),...
                'MeasResp',double(l2_data(N).MeasResp{Species}),...
                'TotalError',double(l2_data(N).TotalError{Species}),...
                'ZPT',double(l2_data(N).ZPT));
            
            l2_data_odin(n)= struct('Date', datestr(dayvn,'dd/mm/yyyy'),...
                'SpeciesNames',char(l2_data(N).SpeciesNames{Species}),...
                'Quality',double(0),'Latitude',double(l2_data(N).Latitude),...
                'Longitude',double(l2_data(N).Longitude),'GMLat',double(GMLat),...
                'GMLon',double(GMLon),'SunZD',double(l2_data(N).SunZD),...
                'ZPT',l2_data(N).ZPT,'Altitudes',{l2_data(N).Altitudes},...
                'Profiles',{{o',double(l2_data(N).Profiles{2}),o',o'}});
            
                 n=n+1;
        end
        N=N+1;
        
        
    end
    %l2_data_odin=l2_data;
    
    
    %% Dataset at one specified altitude
    p=1; % Index for number of scans
    
    while p<=size(S,2)
        tmp_profile= interp1(S(p).Altitudes,S(p).Profile,Altitude);
        tmp_measresp = interp1(S(p).Altitudes,S(p).MeasResp,Altitude);
        
        S_Alt_Odin(p) = struct('SpeciesName',char(S(p).SpeciesName),...
            'Date',char(S(p).Date),...
            'Time',char(S(p).Time),...
            'SunZD', double(S(p).SunZD),...
            'GeodeticLat', double(S(p).GeodeticLat),...
            'GeodeticLon',double(S(p).GeodeticLon),...
            'GeoMagLat',double(S(p).GeoMagLat),...
            'GeoMagLon',double(S(p).GeoMagLon),...
            'Altitude',double(Altitude),...
            'Profile',double(tmp_profile));
        p=p+1;
    end
else
    S_Alt_Odin=[];
    l2_data_odin=[];
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Data analysis for Aura

% For the satellite Aura it reads the data with the function readL2GP.m

d=181+dayn;
l2_data=[]; Lat=[]; GMLat=[]; GMLon=[];

if ~isempty(strfind(SpeciesName,'O3'));
    name=['MLS-Aura_L2GP-O3_v03-30-c01_2009d' num2str(d) '.he5'];
    ext='/O3';
else name=['MLS-Aura_L2GP-OH_v03-30-c01_2009d' num2str(d) '.he5'];
    ext='/OH';
end;
    filename=fullfile(path_data_input_aura, ext, name);
if ~isempty(strfind(SpeciesName,'O3'));
    l2_data=readL2GP(filename,'O3');
else l2_data=readL2GP(filename,'OH');
end;
if isempty(l2_data)
 	  disp('ERROR: no data - l2_data structure empty for ',SpeciesName,' in this day');
 	  return
 	end;
% Only use profiles having 'Quality' higher than 0.6 for O3
if ~isempty(strfind(SpeciesName,'O3'));
    index1=find(l2_data.Quality<=Quality_thr);
    l2_data.L2gpValue(:,index1)=NaN;
    l2_data.Latitude(index1)=NaN;
end;

% Only use profiles having 'Convergence' lower than 1.18 for O3 and 1.1 for
% OH
if ~isempty(strfind(SpeciesName,'O3'));
    index2=find(l2_data.Convergence>=Converg_thr_O3);
    l2_data.L2gpValue(:,index2)=NaN;
    l2_data.Latitude(index2)=NaN;
else
    index2=find(l2_data.Convergence>=Converg_thr_OH);
    l2_data.L2gpValue(:,index2)=NaN;
    l2_data.Latitude(index2)=NaN;
end;

% Altitude to pressure conversion using the ODIN ZPT data
i=1;
if ~isempty(strfind(SpeciesName,'O3'));
ind=find( ~isnan(l2_data_odin(i).ZPT(:,1)) & ~isnan(l2_data_odin(i).ZPT(:,2)) );
odin_z=l2_data_odin(i).ZPT(ind,1);
odin_p=l2_data_odin(i).ZPT(ind,2);
tmp_P=exp(interp1(odin_z,log(odin_p),valt,'linear','extrap'));
else
load ZPT.mat;
odin_z=ZPT(:,1);
odin_p=ZPT(:,2);
%ind=find( ~isnan(Height) & ~isnan(Pres) );
%odin_z=l2_data_odin(i).ZPT(ind,1);
%odin_p=l2_data_odin(i).ZPT(ind,2);
tmp_P=exp(interp1(odin_z,log(odin_p),valt,'linear','extrap'));
end;

%Plot_ZPT(odin_z,odin_p,valt,tmp_P);


%% Aura data at one specified altitude

P_alt= exp(interp1(valt,log(tmp_P),Altitude,'linear','extrap'));

%Number of measured profiles for the Aura satellite in one day

Np = size(l2_data.L2gpValue,2);

N=1; % Index for the structure l2_data
n=1; % Index for the structure S

while N<=Np
    Lat(N)=l2_data.Latitude(N);
    if (Lat(N)~=NaN & Lat(N)<=0)
        tmp_Profile = interp1(log(l2_data.Pressure),l2_data.L2gpValue(:,N),log(P_alt));
        
        [GMLat GMLon]=GDZ2GMA(Altitude,l2_data.Latitude(N),l2_data.Longitude(N));
        GMLat_Aura(N,1)=GMLat;
        GMLon_Aura(N,1)=GMLon;
        S_Alt_Aura(n) = struct('SpeciesName',SpeciesName,...
            'Date', datestr(dayvn,'dd/mm/yyyy'),...
            'Time', datestr(l2_data.Time(N),'HH:MM:SS'),...
            'SunZD', double(l2_data.SolarZenithAngle(N)),...
            'GeodeticLat',double(l2_data.Latitude(N)),...
            'GeodeticLon',double(l2_data.Longitude(N)),...
            'GeoMagLat',double(GMLat),...
            'GeoMagLon', double(GMLon),...
            'Altitude',double(Altitude),...
            'Profile',double(tmp_Profile));
        
        n=n+1;
        
    end
    N=N+1;
end;
%% Aura data for all altitudes

N=1; % Index for the structure l2_data
n=1; % Index for the structure S
% Pressure to altitude conversion using the ODIN ZPT data
tmp_z=interp1(log(odin_p),odin_z,log(l2_data.Pressure),'linear','extrap');

% Create similar ZP data for Aura
o=zeros(length(tmp_z),1);
ZPT_aura=[tmp_z l2_data.Pressure o];

while N<=Np
    Lat(N)=l2_data.Latitude(N);
    if Lat(N)<=0
        [GMLat GMLon]=GDZ2GMA(60,l2_data.Latitude(N),l2_data.Longitude(N));
        
        l2_data_aura(n)= struct('Date', datestr(dayvn,'dd/mm/yyyy'),...
            'SpeciesNames',{{'X',l2_data.swath,'X','X'}},...
            'Quality',double(0),'Latitude',double(l2_data.Latitude(N)),...
            'Longitude',double(l2_data.Longitude(N)),'GMLat',double(GMLat),...
            'GMLon',double(GMLon),'SunZD',double(l2_data.SolarZenithAngle(N)),...
            'ZPT',double(ZPT_aura),'Altitudes',{{o,double(tmp_z),o,o}},...
            'Profiles',{{o',double(l2_data.L2gpValue(:,N)'),o',o'}});
        
        
        n=n+1;
    end
    N=N+1;
    
    
    
end;



end


%ZPT=l2_data_odin(i).ZPT;
%load ZPT.mat
%Height=ZPT(:,1);
%Pres=ZPT(:,2);
%alpha1=-log(Pres(32)/Pres(1))/Height(32);
%alpha2=-log(Pres(34)/Pres(1))/Height(34);
%alpha=(alpha1+alpha2)/2;
%P_80=Pres(1)*exp(-alpha*80);
%Height=[Height; 80];
%Pres=[Pres; P_80];