function plot_zonalmean(zm,species,level_type,clim,ylim,latlim,output_dev,output_path,title_str)

 	figure(1);
 	cla;
 	clf;
 	set(gcf,'Visible','on');
 	set(gcf,'InvertHardcopy','off');
 	set(gcf,'Color',[1 1 1]);
 	
 
 	if strcmp(zm.level_type,'altitude') level_unit='km'; end
 	
 	disp(['Zonal mean species: ',zm.species]);
 	
 	if 1
 	  if (nargin>=4) & ~isempty(clim) & (max(clim)~=0)
 	    scaling=10^(-floor(log10(max(max(clim)))/3)*3);
 	  else
 	    scaling=10^(-floor(log10(max(max(zm.meanvmr(:,5:end))))/3)*3);
 	  end
 	else 
 	  scaling = 1.;
 	end
 	if ~isfinite(scaling) scaling=1.; end;
 	
 	zm.meanvmr=zm.meanvmr.*scaling;
 	zm.medianvmr=zm.medianvmr.*scaling;

 	axes('position', [0.11,0.15,0.81,0.75]);
 	axis([-90 +90 ylim(1) ylim(2)]);
 	
 	axis on;
 	axis tight;
 	
 	meanlat=zm.meanlat;
 
    plotvmr = zm.meanvmr;
 	  log_flag = 0;
 
 	hpc=pcolor(meanlat,zm.levels,plotvmr'); 
 	shading interp;
 	if ((nargin>=4) & ~isempty(clim) & ~log_flag) caxis(clim.*scaling); end;
 	if ((nargin>=4) & ~isempty(clim) & log_flag & min(clim)>0) caxis(log10(clim.*scaling)); end;
 	%
 
 	set(gca,'XLim',latlim);
 	set(gca,'YLim',ylim);
 	hy=ylabel([level_type ' [' level_unit ']']);
 	if strcmp(zm.lat_type,'lat') hx=xlabel('Geomagnetic latitude  [deg]');end; 
 	if strcmp(zm.lat_type,'time') hx=xlabel('Days in July 2009');end; 
 	
    set(hx,'Fontsize',11,'Fontweight','demi');
 	set(hy,'Fontsize',11,'Fontweight','demi')
 	set(gca,'Fontsize',12,'Fontweight','demi');
 	if strcmp(level_type,'pressure') set(gca,'YScale','log'); end
 	if strcmp(level_type,'pressure') set(gca,'YDir','reverse'); end
 	
    
 	YLim=get(gca,'YLim');
 	XLim=get(gca,'XLim');
 	tmp_y=YLim(2)-0.05*abs(YLim(2)-YLim(1));
 	if strcmp(level_type,'pressure')
 	  tmp_y=exp(log(min(YLim))+abs(log(min(YLim))-log(max(YLim)))/20.);
 	end;
 	
 	hcb=colorbar;
 	%cmap=colormap;
 	%cmap (1,:)=1;
 	colormap(jet(16));
 	shading interp;
    
    if clim(1)<0
    load('MartinColormap','mycmap'); set(gcf,'Colormap',mycmap);
    if clim(1)>=-1 
        unit_str='ppmv';
    else
        unit_str='%';    
    end;
    else unit_str='ppmv';
    end;
    axes('position', [0.,0.,1.,1.]);axis off;
 	
 	% bar title 
 	bar_title=[species,' [',unit_str,']'];
 	h=text(0.95,0.5,bar_title,'fontsize' ,13,'interpreter','none','rotation',90,'Fontweight','demi');
 	
    % Plot title
 	if strcmp(zm.name,'O3_zmean_Mag_average') titstr=[zm.species ' Average - Zonal mean'];
    else titstr=[zm.species '  ' zm.startdate ' - Zonal mean'];end;
    if ((nargin>=9) & ~isempty(title_str)) titstr=title_str; end;
 	h=text(0.5,0.925,titstr,'fontsize' ,15,'Fontweight','demi','interpreter','none','horiz','center');
 	
 	  
      out_name = [output_path,zm.name];
 	
 	  % eps output
 	  if ~isempty(strfind(output_dev,'eps'))
        set(gcf,'InvertHardcopy','off');
 	    set(gcf,'PaperType','A4');
 	    set(gcf,'PaperOrientation','landscape');
 	    set(gcf,'PaperPositionMode','auto');
 	    eps_name=[out_name,'.eps'];
        disp(['Printing to file ',eps_name,' ... ']);
        print('-depsc','-f1',eps_name);
 	  end
 
 	
 	  %png output 
 	  if ~isempty(strfind(output_dev,'png'))
        set(gcf,'InvertHardcopy','off');
        set(gcf,'PaperType','A4');
 	    set(gcf,'PaperOrientation','landscape');
 	    set(gcf,'PaperPositionMode','auto');
 	    png_name=[out_name,'.png'];
 	    disp(['Printing to file ',png_name,' ... ']);
 	    print('-dpng','-zbuffer','-f1',[png_name]);
 	  end
 	
 	
 	
 	return
